==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnextranet/extranetvpns/ExtranetVpnKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnextranet.extranetvpns;

import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.SvcId;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of extranetVpn.
 */
public class ExtranetVpnKeys implements KeyInfo<DefaultExtranetVpn> {
    protected SvcId vpnId;
    /**
     * Returns the attribute vpnId.
     *
     * @return vpnId value of vpnId
     */
    public SvcId vpnId() {
        return vpnId;
    }

    /**
     * Sets the value to attribute vpnId.
     *
     * @param vpnId value of vpnId
     */
    public void vpnId(SvcId vpnId) {
        this.vpnId = vpnId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(vpnId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof ExtranetVpnKeys) {
            ExtranetVpnKeys other = (ExtranetVpnKeys) obj;
            return
                Objects.equals(vpnId, other.vpnId);
        }
        return false;
    }
}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/vpnextranet/extranetvpns/ExtranetVpnKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.vpnextranet.extranetvpns;

import org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc.SvcId;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of extranetVpn.
 */
public class ExtranetVpnKeys implements KeyInfo<DefaultExtranetVpn> {
    protected SvcId vpnId;
    /**
     * Returns the attribute vpnId.
     *
     * @return vpnId value of vpnId
     */
    public SvcId vpnId() {
        return vpnId;
    }

    /**
     * Sets the value to attribute vpnId.
     *
     * @param vpnId value of vpnId
     */
    public void vpnId(SvcId vpnId) {
        this.vpnId = vpnId;
    }


    @Override
    public int hashCode() {
        return Objects.hash(vpnId);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof ExtranetVpnKeys) {
            ExtranetVpnKeys other = (ExtranetVpnKeys) obj;
            return
                Objects.deepEquals(vpnId, other.vpnId);
        }
        return false;
    }
}
